@@ -45,11 +45,11 @@ Metabolomics::Banks - Perl extension to build metabolite banks for metabolomics
 
 =head1 VERSION
 
-Version 0.1
+Version 0.2 - Adding POD
 
 =cut
 
-our $VERSION = '0.1';
+our $VERSION = '0.2';
 
 
 =head1 SYNOPSIS
@@ -432,6 +432,10 @@ sub __refPeak__ {
     $self->{_ANNOTATION_TYPE_} = undef ; # STRING as adducts, fragment or isotope
     $self->{_ANNOTATION_NAME_} = undef ; # STRING for metabolite common name
     $self->{_ANNOTATION_FORMULA_} = undef ; # STRING for metabolite molecular formula
+    $self->{_ANNOTATION_INCHIKEY_} = undef ; # STRING for metabolite inchikey representation
+    $self->{_ANNOTATION_SMILES_} = undef ; # STRING for metabolite smiles representation
+    $self->{_ANNOTATION_IS_A_METABOLITE_} = undef ; # STRING for metabolite status
+    $self->{_ANNOTATION_IS_A_PRECURSOR_} = undef ; # STRING for metabolite status
 
     return $self ;
 }
@@ -861,6 +865,31 @@ sub _setPeak_ANNOTATION_ID {
 }
 ### END of SUB
 
+=item PRIVATE_ONLY _getPeak_ANNOTATION_FORMULA
+
+	## Description : _getPeak_ANNOTATION_FORMULA
+	## Input : void
+	## Output : $VALUE
+	## Usage : my ( $VALUE ) = _getPeak_ANNOTATION_FORMULA () ;
+
+=cut
+
+## START of SUB
+sub _getPeak_ANNOTATION_FORMULA {
+    ## Retrieve Values
+    my $self = shift ;
+    
+    my $VALUE = undef ;
+    
+    if ( (defined $self->{_ANNOTATION_FORMULA_}) and ( $self->{_ANNOTATION_FORMULA_} ne '' ) ) {	$VALUE = $self->{_ANNOTATION_FORMULA_} ; }
+    else {	 $VALUE = undef ; 
+    	#warn "[WARN] the method _getPeak_ANNOTATION_FORMULA can't _getPeak a undef or non numerical value\n" ; 
+	}
+    
+    return ( $VALUE ) ;
+}
+### END of SUB
+
 =item PRIVATE_ONLY _setPeak_ANNOTATION_FORMULA
 
 	## Description : _setPeak_ANNOTATION_FORMULA
@@ -905,6 +934,196 @@ sub _setPeak_ANNOTATION_ONLY_IN {
 }
 ### END of SUB
 
+=item PRIVATE_ONLY _getPeak_ANNOTATION_SMILES
+
+	## Description : _getPeak_ANNOTATION_SMILES
+	## Input : void
+	## Output : $VALUE
+	## Usage : my ( $VALUE ) = _getPeak_ANNOTATION_SMILES () ;
+
+=cut
+
+## START of SUB
+sub _getPeak_ANNOTATION_SMILES {
+    ## Retrieve Values
+    my $self = shift ;
+    
+    my $VALUE = undef ;
+    
+    if ( (defined $self->{_ANNOTATION_SMILES_}) and ( $self->{_ANNOTATION_SMILES_} ne '' ) ) {	$VALUE = $self->{_ANNOTATION_SMILES_} ; }
+    else {	 $VALUE = undef ; 
+    	#warn "[WARN] the method _getPeak_ANNOTATION_SMILES can't _getPeak a undef or non numerical value\n" ; 
+	}
+    
+    return ( $VALUE ) ;
+}
+### END of SUB
+
+=item PRIVATE_ONLY _setPeak_ANNOTATION_SMILES
+
+	## Description : _setPeak_ANNOTATION_SMILES
+	## Input : $VALUE
+	## Output : TRUE
+	## Usage : _setPeak_ANNOTATION_SMILES ( $VALUE ) ;
+
+=cut
+
+## START of SUB
+sub _setPeak_ANNOTATION_SMILES {
+    ## Retrieve Values
+    my $self = shift ;
+    my ( $VALUE ) = @_;
+    
+    if ( (defined $VALUE) and ($VALUE ne '')  ) {	$self->{_ANNOTATION_SMILES_} = $VALUE ; }
+    else {	carp "[ERROR] the method _setPeak_ANNOTATION_SMILES can't set any undef or non numerical value\n" ; }
+    
+    return (0) ;
+}
+### END of SUB
+
+=item PRIVATE_ONLY _getPeak_ANNOTATION_INCHIKEY
+
+	## Description : _getPeak_ANNOTATION_INCHIKEY
+	## Input : void
+	## Output : $VALUE
+	## Usage : my ( $VALUE ) = _getPeak_ANNOTATION_INCHIKEY () ;
+
+=cut
+
+## START of SUB
+sub _getPeak_ANNOTATION_INCHIKEY {
+    ## Retrieve Values
+    my $self = shift ;
+    
+    my $VALUE = undef ;
+    
+    if ( (defined $self->{_ANNOTATION_INCHIKEY_}) and ( $self->{_ANNOTATION_INCHIKEY_} ne '' ) ) {	$VALUE = $self->{_INCHIKEY_} ; }
+    else {	 $VALUE = undef ; 
+    	#warn "[WARN] the method _getPeak_ANNOTATION_INCHIKEY can't _getPeak a undef or non numerical value\n" ; 
+	}
+    
+    return ( $VALUE ) ;
+}
+### END of SUB
+
+=item PRIVATE_ONLY _setPeak_ANNOTATION_INCHIKEY
+
+	## Description : _setPeak_ANNOTATION_INCHIKEY
+	## Input : $VALUE
+	## Output : TRUE
+	## Usage : _setPeak_ANNOTATION_INCHIKEY ( $VALUE ) ;
+
+=cut
+
+## START of SUB
+sub _setPeak_ANNOTATION_INCHIKEY {
+    ## Retrieve Values
+    my $self = shift ;
+    my ( $VALUE ) = @_;
+    
+    if ( (defined $VALUE) and ($VALUE ne '')  ) {	$self->{_ANNOTATION_INCHIKEY_} = $VALUE ; }
+    else {	carp "[ERROR] the method _setPeak_ANNOTATION_INCHIKEY can't set any undef or non numerical value\n" ; }
+    
+    return (0) ;
+}
+### END of SUB
+
+=item PRIVATE_ONLY _getPeak_ANNOTATION_IS_A_PRECURSOR
+
+	## Description : _getPeak_ANNOTATION_IS_A_PRECURSOR
+	## Input : void
+	## Output : $VALUE
+	## Usage : my ( $VALUE ) = _getPeak_ANNOTATION_IS_A_PRECURSOR () ;
+
+=cut
+
+## START of SUB
+sub _getPeak_ANNOTATION_IS_A_PRECURSOR {
+    ## Retrieve Values
+    my $self = shift ;
+    
+    my $VALUE = undef ;
+    
+    if ( (defined $self->{_ANNOTATION_IS_A_PRECURSOR_}) and ( $self->{_ANNOTATION_IS_A_PRECURSOR_} ne '' ) ) {	$VALUE = $self->{_ANNOTATION_IS_A_PRECURSOR_} ; }
+    else {	 $VALUE = undef ; 
+    	#warn "[WARN] the method _getPeak_ANNOTATION_IS_A_PRECURSOR can't _getPeak a undef or non numerical value\n" ; 
+	}
+    
+    return ( $VALUE ) ;
+}
+### END of SUB
+
+=item PRIVATE_ONLY _setPeak_ANNOTATION_IS_A_PRECURSOR
+
+	## Description : _setPeak_ANNOTATION_IS_A_PRECURSOR
+	## Input : $VALUE
+	## Output : TRUE
+	## Usage : _setPeak_ANNOTATION_IS_A_PRECURSOR ( $VALUE ) ;
+
+=cut
+
+## START of SUB
+sub _setPeak_ANNOTATION_IS_A_PRECURSOR {
+    ## Retrieve Values
+    my $self = shift ;
+    my ( $VALUE ) = @_;
+    
+    if ( (defined $VALUE) and ($VALUE ne '')  ) {	$self->{_ANNOTATION_IS_A_PRECURSOR_} = $VALUE ; }
+    else {	carp "[ERROR] the method _setPeak_ANNOTATION_IS_A_PRECURSOR can't set any undef or non numerical value\n" ; }
+    
+    return (0) ;
+}
+### END of SUB
+
+=item PRIVATE_ONLY _getPeak_ANNOTATION_IS_A_PRECURSOR
+
+	## Description : _getPeak_ANNOTATION_IS_A_PRECURSOR
+	## Input : void
+	## Output : $VALUE
+	## Usage : my ( $VALUE ) = _getPeak_ANNOTATION_IS_A_PRECURSOR () ;
+
+=cut
+
+## START of SUB
+sub _getPeak_ANNOTATION_IS_A_METABOLITE {
+    ## Retrieve Values
+    my $self = shift ;
+    
+    my $VALUE = undef ;
+    
+    if ( (defined $self->{_ANNOTATION_IS_A_METABOLITE_}) and ( $self->{_ANNOTATION_IS_A_METABOLITE_} ne '' ) ) {	$VALUE = $self->{_ANNOTATION_IS_A_METABOLITE_} ; }
+    else {	 $VALUE = undef ; 
+    	#warn "[WARN] the method _getPeak_ANNOTATION_IS_A_METABOLITE can't _getPeak a undef or non numerical value\n" ; 
+	}
+    
+    return ( $VALUE ) ;
+}
+### END of SUB
+
+=item PRIVATE_ONLY _setPeak_ANNOTATION_IS_A_METABOLITE
+
+	## Description : _setPeak_ANNOTATION_IS_A_METABOLITE
+	## Input : $VALUE
+	## Output : TRUE
+	## Usage : _setPeak_ANNOTATION_IS_A_METABOLITE ( $VALUE ) ;
+
+=cut
+
+## START of SUB
+sub _setPeak_ANNOTATION_IS_A_METABOLITE {
+    ## Retrieve Values
+    my $self = shift ;
+    my ( $VALUE ) = @_;
+    
+    if ( (defined $VALUE) and ($VALUE ne '')  ) {	$self->{_ANNOTATION_IS_A_METABOLITE_} = $VALUE ; }
+    else {	carp "[ERROR] the method _setPeak_ANNOTATION_IS_A_METABOLITE can't set any undef or non numerical value\n" ; }
+    
+    return (0) ;
+}
+### END of SUB
+
+
+
 __END__
 
 =back
