@@ -50,12 +50,12 @@ Metabolomics::Fragment::Annotation - Perl extension for fragment annotation in m
 
 =head1 VERSION
 
-Version 0.6.2_01 - Go to 0.6.3
+Version 0.6.3 - Adding POD and PhytoHUB module
 
 
 =cut
 
-our $VERSION = '0.6.2_01';
+our $VERSION = '0.6.3';
 
 
 =head1 SYNOPSIS
@@ -243,9 +243,16 @@ sub compareExpMzToTheoMzList {
     		
 #    		print "\nFOR frag $fragMz - MIN is: $$min and MAX is: $$max\n" ;
     		
-    		my ($currentPpmError, $currentDeltaErrorMmu) = (undef, undef) ;
-    		my ($currentAnnotName, $currentComputedMz, $currentAnnotType, $currentAnnotID, $currentAnnotInNegMode, $currentAnnotInPosMode) = (undef, undef, undef, undef, undef, undef) ;
-    		my ($annotName, $computedMz, $annotType, $annotID, $annotInNegMode, $annotInPosMode, $deltaErrorMmu, $deltaErrorPpm) = (undef, undef, undef, undef, undef, undef, 0) ;
+    		my ( $deltaErrorMmu, $deltaErrorPpm) = ( undef, 0 ) ;
+    		
+    		my ( $currentPpmError, $currentDeltaErrorMmu) = ( undef, undef ) ;
+    		my ( $currentAnnotName, $currentComputedMz, $currentAnnotType, $currentAnnotID) =  ( undef, undef, undef, undef ) ;
+    		my ( $currentAnnotInNegMode, $currentAnnotInPosMode, $currentAnnotFormula, $currentAnnotSmiles) = ( undef, undef, undef, undef ) ;
+    		my ( $currentAnnotInchikey, $currentAnnotIsAMetabolite, $currentAnnotIsAPrecursor) = ( undef, undef, undef ) ;
+    		
+    		my ( $annotName, $computedMz, $annotType, $annotID) = ( undef, undef, undef, undef ) ;
+    		my ( $annotInNegMode, $annotInPosMode, $annotFormula, $annotSmiles) = ( undef, undef, undef, undef ) ;
+    		my ( $annotInchikey, $annotIsAMetabolite, $annotIsAPrecursor) = ( undef, undef, undef ) ;
     		
     		foreach my $theoFrag (@{$theoFragments}) {
     			
@@ -253,15 +260,20 @@ sub compareExpMzToTheoMzList {
     			
     			if (  ($motifMz > $$min ) and ($motifMz < $$max)  ) {
     				
+    				$annotName = $theoFrag-> _getPeak_ANNOTATION_NAME();
+    				$computedMz = $theoFrag->_getPeak_COMPUTED_MONOISOTOPIC_MASS();
+    				$annotType = $theoFrag->_getPeak_ANNOTATION_TYPE() ;
+    				$annotID = $theoFrag->_getPeak_ANNOTATION_ID() if $theoFrag->_getPeak_ANNOTATION_ID ;
     				
-    				my $annotName = $theoFrag-> _getPeak_ANNOTATION_NAME();
-    				my $computedMz = $theoFrag->_getPeak_COMPUTED_MONOISOTOPIC_MASS();
-    				my $annotType = $theoFrag->_getPeak_ANNOTATION_TYPE() ;
-    				my $annotID = $theoFrag->_getPeak_ANNOTATION_ID() if $theoFrag->_getPeak_ANNOTATION_ID ;
-    				
-    				my $annotInNegMode =  $theoFrag->_getPeak_ANNOTATION_IN_NEG_MODE() if $theoFrag->_getPeak_ANNOTATION_IN_NEG_MODE() ;
-    				my $annotInPosMode =  $theoFrag->_getPeak_ANNOTATION_IN_POS_MODE() if $theoFrag->_getPeak_ANNOTATION_IN_POS_MODE() ;
+    				$annotInNegMode =  $theoFrag->_getPeak_ANNOTATION_IN_NEG_MODE() if $theoFrag->_getPeak_ANNOTATION_IN_NEG_MODE() ;
+    				$annotInPosMode =  $theoFrag->_getPeak_ANNOTATION_IN_POS_MODE() if $theoFrag->_getPeak_ANNOTATION_IN_POS_MODE() ;
     				
+    				$annotFormula = $theoFrag->_getPeak_ANNOTATION_FORMULA() if $theoFrag->_getPeak_ANNOTATION_FORMULA() ;
+    				$annotSmiles = $theoFrag->_getPeak_ANNOTATION_SMILES() if $theoFrag->_getPeak_ANNOTATION_SMILES() ;
+    				$annotInchikey = $theoFrag->_getPeak_ANNOTATION_INCHIKEY() if $theoFrag->_getPeak_ANNOTATION_INCHIKEY() ;
+    				$annotIsAMetabolite = $theoFrag->_getPeak_ANNOTATION_IS_A_METABOLITE() if ($theoFrag->_getPeak_ANNOTATION_IS_A_METABOLITE() and $theoFrag->_getPeak_ANNOTATION_IS_A_METABOLITE() != 0) ;
+    				$annotIsAPrecursor = $theoFrag->_getPeak_ANNOTATION_IS_A_PRECURSOR() if ($theoFrag->_getPeak_ANNOTATION_IS_A_PRECURSOR() and $theoFrag->_getPeak_ANNOTATION_IS_A_PRECURSOR() != 0) ;
+    				    				
 #    				print $annotInNegMode if $annotInNegMode ;
 #    				print $annotInPosMode if $annotInPosMode ;
     				
@@ -280,6 +292,11 @@ sub compareExpMzToTheoMzList {
 						$currentAnnotID = $annotID ;
 						$currentAnnotInNegMode = $annotInNegMode ;
 						$currentAnnotInPosMode = $annotInPosMode ;
+						$currentAnnotFormula = $annotFormula ;
+						$currentAnnotSmiles = $annotSmiles ;
+						$currentAnnotInchikey = $annotInchikey ;
+						$currentAnnotIsAMetabolite = $annotIsAMetabolite ;
+						$currentAnnotIsAPrecursor = $annotIsAPrecursor ;
 	    				
     				}
     				else {
@@ -296,6 +313,11 @@ sub compareExpMzToTheoMzList {
 							$currentAnnotID = $annotID ;
 							$currentAnnotInNegMode = $annotInNegMode ;
 							$currentAnnotInPosMode = $annotInPosMode ;
+							$currentAnnotFormula = $annotFormula ;
+							$currentAnnotSmiles = $annotSmiles ;
+							$currentAnnotInchikey = $annotInchikey ;
+							$currentAnnotIsAMetabolite = $annotIsAMetabolite ;
+							$currentAnnotIsAPrecursor = $annotIsAPrecursor ;
     					}
     					elsif ($currentPpmError == $deltaErrorPpm ) {
     						next ;
@@ -314,6 +336,12 @@ sub compareExpMzToTheoMzList {
     			$expFrag->_setPeak_ANNOTATION_IN_NEG_MODE($currentAnnotInNegMode) if (defined $currentAnnotInNegMode);
     			$expFrag->_setPeak_ANNOTATION_IN_POS_MODE($currentAnnotInPosMode) if (defined $currentAnnotInPosMode);
     			
+    			$expFrag->_setPeak_ANNOTATION_FORMULA($currentAnnotFormula) if (defined $currentAnnotFormula);
+    			$expFrag->_setPeak_ANNOTATION_SMILES($currentAnnotSmiles) if (defined $currentAnnotSmiles);
+    			$expFrag->_setPeak_ANNOTATION_INCHIKEY($currentAnnotInchikey) if (defined $currentAnnotInchikey);
+    			$expFrag->_setPeak_ANNOTATION_IS_A_METABOLITE($currentAnnotIsAMetabolite) if (defined $currentAnnotIsAMetabolite);
+    			$expFrag->_setPeak_ANNOTATION_IS_A_PRECURSOR($currentAnnotIsAPrecursor) if (defined $currentAnnotIsAPrecursor);
+    			
 #    			print "\tOK -> $motifMz MATCHING WITH $fragMz and ppm error of $currentPpmError ($currentAnnotInPosMode)\n" ;
 
     			} ## Matching !!
